==> fuel-ui-0.4.1-3.tgz: package/esm/components/DatePicker/datePicker.module.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { NgModule } from "@angular/core";
import { CommonModule } from "@angular/common";
import { FormsModule } from "@angular/forms";
import { FuiInfiniteScrollerModule } from "../infiniteScroller/infiniteScroller";
export { DatePickerCalendar } from "./datePickerCalendar";
export { DatePicker } from "./datePicker";
export { DatePickerField, DatePickerFieldStyler } from "./datePickerField";
export { DateRangePicker, StartDateField, EndDateField } from "./dateRangePicker";
import { DatePickerCalendar } from "./datePickerCalendar";
import { DatePicker } from "./datePicker";
import { DatePickerField, DatePickerFieldStyler } from "./datePickerField";
import { DateRangePicker, StartDateField, EndDateField } from "./dateRangePicker";
const datePickerDirectives = [
    DatePicker,
    DatePickerCalendar,
    DatePickerField,
    DatePickerFieldStyler,
    DateRangePicker,
    StartDateField,
    EndDateField
];
export let FuiDatePickerModule = class FuiDatePickerModule {
};
FuiDatePickerModule = __decorate([
    NgModule({
        imports: [CommonModule, FormsModule, FuiInfiniteScrollerModule],
        declarations: datePickerDirectives,
        exports: datePickerDirectives
    }), 
    __metadata('design:paramtypes', [])
], FuiDatePickerModule);

==> fuel-ui-0.4.1-4.tgz: package/esm/components/DatePicker/datePicker.module.js <==
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
var __metadata = (this && this.__metadata) || function (k, v) {
    if (typeof Reflect === "object" && typeof Reflect.metadata === "function") return Reflect.metadata(k, v);
};
import { NgModule } from "@angular/core";
import { CommonModule } from "@angular/common";
import { FormsModule } from "@angular/forms";
import { FuiInfiniteScrollerModule } from "../InfiniteScroller/InfiniteScroller";
export { DatePickerCalendar } from "./DatePickerCalendar";
export { DatePicker } from "./DatePicker";
export { DatePickerField, DatePickerFieldStyler } from "./DatePickerField";
export { DateRangePicker, StartDateField, EndDateField } from "./DateRangePicker";
import { DatePickerCalendar } from "./DatePickerCalendar";
import { DatePicker } from "./DatePicker";
import { DatePickerField, DatePickerFieldStyler } from "./DatePickerField";
import { DateRangePicker, StartDateField, EndDateField } from "./DateRangePicker";
const datePickerDirectives = [
    DatePicker,
    DatePickerCalendar,
    DatePickerField,
    DatePickerFieldStyler,
    DateRangePicker,
    StartDateField,
    EndDateField
];
export let FuiDatePickerModule = class FuiDatePickerModule {
};
FuiDatePickerModule = __decorate([
    NgModule({
        imports: [CommonModule, FormsModule, FuiInfiniteScrollerModule],
        declarations: datePickerDirectives,
        exports: datePickerDirectives
    }), 
    __metadata('design:paramtypes', [])
], FuiDatePickerModule);
